Add removeExtras(String...) prototype per API review.

Per API review, adding a convenience prototype of the removeExtras method.

Bug: 28295516
Change-Id: Icc0e040516c06205540c5683bde16882a73a89d6
diff --git a/telecomm/java/android/telecom/Connection.java b/telecomm/java/android/telecom/Connection.java
index d83cdb8..a5e3c461 100644
--- a/telecomm/java/android/telecom/Connection.java
+++ b/telecomm/java/android/telecom/Connection.java
@@ -35,6 +35,7 @@
 import android.view.Surface;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Set;
@@ -1972,9 +1973,9 @@
     }
 
     /**
      * Removes an extra from this {@code Connection}.
      *
      * @param keys The key of the extra key to remove.
      */
     public final void removeExtras(List<String> keys) {
         if (mExtras != null) {
@@ -1993,6 +1994,15 @@
     }
 
     /**
+     * Removes extras from this {@code Connection}.
+     *
+     * @param keys The keys of the extras to remove.
+     */
+    public final void removeExtras(String ... keys) {
+        removeExtras(Arrays.asList(keys));
+    }
+
+    /**
      * Notifies this Connection that the {@link #getAudioState()} property has a new value.
      *
      * @param state The new connection audio state.
@@ -1972,9 +1973,9 @@
 
     /**
-     * Removes an extra from this {@code Connection}.
+     * Removes extras from this {@code Connection}.
      *
@@ -1972,9 +1973,9 @@
      *
-     * @param keys The key of the extra key to remove.
+     * @param keys The keys of the extras to remove.
      */
     public final void removeExtras(List<String> keys) {